Index: third_party/WebKit/Source/modules/accessibility/AXObjectCacheImpl.h |
diff --git a/third_party/WebKit/Source/modules/accessibility/AXObjectCacheImpl.h b/third_party/WebKit/Source/modules/accessibility/AXObjectCacheImpl.h |
index c01b3fb41058cd91313960b6d06cf0de943d4c6d..6e130da47b23c26fa72e369674363a9f7a03dc61 100644 |
--- a/third_party/WebKit/Source/modules/accessibility/AXObjectCacheImpl.h |
+++ b/third_party/WebKit/Source/modules/accessibility/AXObjectCacheImpl.h |
@@ -32,7 +32,7 @@ |
#include <memory> |
#include "core/dom/AXObjectCache.h" |
#include "modules/ModulesExport.h" |
-#include "modules/accessibility/AXObject.h" |
+#include "modules/accessibility/AXObjectImpl.h" |
#include "platform/wtf/Forward.h" |
#include "platform/wtf/HashMap.h" |
#include "platform/wtf/HashSet.h" |
@@ -54,7 +54,7 @@ class MODULES_EXPORT AXObjectCacheImpl : public AXObjectCache { |
~AXObjectCacheImpl(); |
DECLARE_VIRTUAL_TRACE(); |
- AXObject* FocusedObject(); |
+ AXObjectImpl* FocusedObject(); |
void Dispose() override; |
@@ -76,9 +76,9 @@ class MODULES_EXPORT AXObjectCacheImpl : public AXObjectCache { |
// Called by a node when text or a text equivalent (e.g. alt) attribute is |
// changed. |
void TextChanged(LayoutObject*) override; |
- void TextChanged(AXObject*); |
+ void TextChanged(AXObjectImpl*); |
// Called when a node has just been attached, so we can make sure we have the |
// right subclass of AXObject. |
void UpdateCacheAfterNodeIsAttached(Node*) override; |
void HandleAttributeChanged(const QualifiedName& attr_name, |
@@ -116,27 +116,27 @@ class MODULES_EXPORT AXObjectCacheImpl : public AXObjectCache { |
void OnTouchAccessibilityHover(const IntPoint&) override; |
// Returns the root object for the entire document. |
- AXObject* RootObject(); |
+ AXObjectImpl* RootObject(); |
- AXObject* ObjectFromAXID(AXID id) const { return objects_.at(id); } |
- AXObject* Root(); |
+ AXObjectImpl* ObjectFromAXID(AXID id) const { return objects_.at(id); } |
+ AXObjectImpl* Root(); |
// used for objects without backing elements |
- AXObject* GetOrCreate(AccessibilityRole); |
- AXObject* GetOrCreate(LayoutObject*); |
- AXObject* GetOrCreate(Node*); |
- AXObject* GetOrCreate(AbstractInlineTextBox*); |
+ AXObjectImpl* GetOrCreate(AccessibilityRole); |
+ AXObjectImpl* GetOrCreate(LayoutObject*); |
+ AXObjectImpl* GetOrCreate(Node*); |
+ AXObjectImpl* GetOrCreate(AbstractInlineTextBox*); |
- // will only return the AXObject if it already exists |
- AXObject* Get(Node*); |
- AXObject* Get(LayoutObject*); |
- AXObject* Get(AbstractInlineTextBox*); |
+ // will only return the AXObjectImpl if it already exists |
+ AXObjectImpl* Get(Node*); |
+ AXObjectImpl* Get(LayoutObject*); |
+ AXObjectImpl* Get(AbstractInlineTextBox*); |
- AXObject* FirstAccessibleObjectFromNode(const Node*); |
+ AXObjectImpl* FirstAccessibleObjectFromNode(const Node*); |
void Remove(AXID); |
- void ChildrenChanged(AXObject*); |
+ void ChildrenChanged(AXObjectImpl*); |
void HandleActiveDescendantChanged(Node*); |
void HandleAriaRoleChanged(Node*); |
@@ -146,7 +146,7 @@ class MODULES_EXPORT AXObjectCacheImpl : public AXObjectCache { |
bool AccessibilityEnabled(); |
bool InlineTextBoxAccessibilityEnabled(); |
- void RemoveAXID(AXObject*); |
+ void RemoveAXID(AXObjectImpl*); |
AXID GenerateAXID() const; |
@@ -156,7 +156,7 @@ class MODULES_EXPORT AXObjectCacheImpl : public AXObjectCache { |
void PostNotification(LayoutObject*, AXNotification); |
void PostNotification(Node*, AXNotification); |
- void PostNotification(AXObject*, AXNotification); |
+ void PostNotification(AXObjectImpl*, AXNotification); |
// |
// Aria-owns support. |
@@ -164,10 +164,10 @@ class MODULES_EXPORT AXObjectCacheImpl : public AXObjectCache { |
// Returns true if the given object's position in the tree was due to |
// aria-owns. |
- bool IsAriaOwned(const AXObject*) const; |
+ bool IsAriaOwned(const AXObjectImpl*) const; |
// Returns the parent of the given object due to aria-owns. |
- AXObject* GetAriaOwnedParent(const AXObject*) const; |
+ AXObjectImpl* GetAriaOwnedParent(const AXObjectImpl*) const; |
// Given an object that has an aria-owns attributes, and a vector of ids from |
// the value of that attribute, updates the internal state to reflect the new |
@@ -178,9 +178,9 @@ class MODULES_EXPORT AXObjectCacheImpl : public AXObjectCache { |
// If one or more ids aren't found, they're added to a lookup table so that if |
// an element with that id appears later, it can be added when you call |
// updateTreeIfElementIdIsAriaOwned. |
- void UpdateAriaOwns(const AXObject* owner, |
+ void UpdateAriaOwns(const AXObjectImpl* owner, |
const Vector<String>& id_vector, |
- HeapVector<Member<AXObject>>& owned_children); |
+ HeapVector<Member<AXObjectImpl>>& owned_children); |
// Given an element in the DOM tree that was either just added or whose id |
// just changed, check to see if another object wants to be its parent due to |
@@ -189,16 +189,16 @@ class MODULES_EXPORT AXObjectCacheImpl : public AXObjectCache { |
void UpdateTreeIfElementIdIsAriaOwned(Element*); |
protected: |
- void PostPlatformNotification(AXObject*, AXNotification); |
+ void PostPlatformNotification(AXObjectImpl*, AXNotification); |
void LabelChanged(Element*); |
- AXObject* CreateFromRenderer(LayoutObject*); |
- AXObject* CreateFromNode(Node*); |
- AXObject* CreateFromInlineTextBox(AbstractInlineTextBox*); |
+ AXObjectImpl* CreateFromRenderer(LayoutObject*); |
+ AXObjectImpl* CreateFromNode(Node*); |
+ AXObjectImpl* CreateFromInlineTextBox(AbstractInlineTextBox*); |
private: |
Member<Document> document_; |
- HeapHashMap<AXID, Member<AXObject>> objects_; |
+ HeapHashMap<AXID, Member<AXObjectImpl>> objects_; |
// LayoutObject and AbstractInlineTextBox are not on the Oilpan heap so we |
// do not use HeapHashMap for those mappings. |
HashMap<LayoutObject*, AXID> layout_object_mapping_; |
@@ -243,13 +243,13 @@ class MODULES_EXPORT AXObjectCacheImpl : public AXObjectCache { |
HashMap<String, std::unique_ptr<HashSet<AXID>>> id_to_aria_owners_mapping_; |
TaskRunnerTimer<AXObjectCacheImpl> notification_post_timer_; |
- HeapVector<std::pair<Member<AXObject>, AXNotification>> |
+ HeapVector<std::pair<Member<AXObjectImpl>, AXNotification>> |
notifications_to_post_; |
void NotificationPostTimerFired(TimerBase*); |
- AXObject* FocusedImageMapUIElement(HTMLAreaElement*); |
+ AXObjectImpl* FocusedImageMapUIElement(HTMLAreaElement*); |
- AXID GetOrCreateAXID(AXObject*); |
+ AXID GetOrCreateAXID(AXObjectImpl*); |
void TextChanged(Node*); |
bool NodeIsTextControl(const Node*); |
@@ -76,9 +76,9 @@ class MODULES_EXPORT AXObjectCacheImpl : public AXObjectCache { |
// Called when a node has just been attached, so we can make sure we have the |
- // right subclass of AXObject. |
+ // right subclass of AXObjectImpl. |
void UpdateCacheAfterNodeIsAttached(Node*) override; |
void HandleAttributeChanged(const QualifiedName& attr_name, |